// DATE.CPP - Date class implementation


#include <iomanip.h>
#include "date.h"

// Define and initialize the static class members.

char Date::delim = '-'; 
Date::DateFormat Date::currentFormat = Date::mmddyyyy;


Date::Date()
{
  month = 0;
  day = 0;
  year = 0;
}

Date::Date( int m, int d, int y )
{
  month = m;
  day = d;
  year = y;
}

Date::Date( long yyyymmddV )
{
  year = yyyymmddV / 10000;
  month = (yyyymmddV / 100) % 100;
  day = yyyymmddV % 100;
}

void Date::SetDelimiter( char ch )
{
  delim = ch;
}

void Date::SetFormat( DateFormat fmt )
{
  currentFormat = fmt;
}

bool Date::EqualTo( const Date & d2 )
{
  return (year == d2.year) && (month == d2.month)
     && (day == d2.day);
}

istream & operator >>( istream & inp, Date & D )
{
  long yyyymmddV;
  inp >> yyyymmddV;
  D.year = yyyymmddV / 10000;
  D.month = (yyyymmddV / 100) % 100;
  D.day = yyyymmddV % 100;
  return inp;
}

ostream & operator <<( ostream & os, const Date & D )
{
  char * monthName[] = {"Jan","Feb","Mar","Apr","May",
          "Jun","Jul","Aug","Sep","Oct","Nov","Dec"};  
  
  // Save current fill character before changing.
  int saveFillChar = os.fill('0');
  
  switch( D.currentFormat )
  {
    case Date::ddmmyyyy:
      os << setw(2) << D.day << D.delim << setw(2) 
         << D.month << D.delim << D.year;
      break;
    case Date::mmddyyyy:
      os << setw(2) << D.month << D.delim << setw(2) 
         << D.day << D.delim << D.year;
      break;
    case Date::ddmmmyyyy:
      os << D.day << D.delim << monthName[D.month-1] 
         << D.delim << D.year;
      break;
  }
  os.fill( saveFillChar );  // Restore previous fill character
  return os;
}






